@@ -8,7 +8,7 @@
 #include "removecollectionrecursivetask.h"
 
 #include "imapresource_debug.h"
-#include <Akonadi/KMime/MessageFlags>
+#include <Akonadi/MessageFlags>
 #include <KIMAP/CloseJob>
 #include <KIMAP/DeleteJob>
 #include <KIMAP/ExpungeJob>
@@ -23,9 +23,7 @@ RemoveCollectionRecursiveTask::RemoveCollectionRecursiveTask(const ResourceState
 {
 }
 
-RemoveCollectionRecursiveTask::~RemoveCollectionRecursiveTask()
-{
-}
+RemoveCollectionRecursiveTask::~RemoveCollectionRecursiveTask() = default;
 
 void RemoveCollectionRecursiveTask::doStart(KIMAP::Session *session)
 {
